pub enum PollIngressSingleResult {
None,
PacketProcessed,
SocketStateChanged,
}Expand description
Result returned by Interface::poll_ingress_single.
This contains information on whether a packet was processed or not, and whether it might’ve affected socket states.
Variants
None
No packet was processed. You don’t need to call Interface::poll_ingress_single
again, until more packets arrive.
Socket state is guaranteed to not have changed.
PacketProcessed
A packet was processed.
There may be more packets in the device’s RX queue, so you should call Interface::poll_ingress_single again.
Socket state is guaranteed to not have changed.
SocketStateChanged
A packet was processed, which might have caused socket state to change.
There may be more packets in the device’s RX queue, so you should call Interface::poll_ingress_single again.
You should check the state of sockets again for received data or completion of operations.